/*
 * Copyright 2007 by Kappich Systemberatung, Aachen
 * Copyright 2004 by Kappich+Kniß Systemberatung, Aachen
 * 
 * This file is part of de.bsvrz.dav.daf.
 * 
 * de.bsvrz.dav.daf is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * de.bsvrz.dav.daf is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with de.bsvrz.dav.daf; If not, see <http://www.gnu.org/licenses/>.
 */

package de.bsvrz.dav.daf.communication.dataRepresentation.datavalue;

import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;

/**
 * Diese Klasse stellt die Attribute und Funktionalitäten des Datentyps byte zur Verfügung.
 *
 * @author Kappich Systemberatung
 * @version $Revision$
 */
public class ByteAttribute extends DataValue {

	/** Der Bytewert */
	private byte _byte;

	/** Erzeugt ein neues Objekt ohne Parameter. Die Parameter werden zu einem Späteren Zeitpunkt über die read-Methode eingelesen. */
	public ByteAttribute() {
		_type = BYTE_TYPE;
	}

	/**
	 * Erzeugt ein neues Objekt mit den gegebenen Parametern.
	 *
	 * @param _b byte
	 */
	public ByteAttribute(byte _b) {
		_type = BYTE_TYPE;
		_byte = _b;
	}


	public final Object getValue() {
		return new Byte(_byte);
	}

	public final DataValue cloneObject() {
		return new ByteAttribute(_byte);
	}


	public final String parseToString() {
		return "Byte: " + _byte + "\n";
	}


	public final void write(DataOutputStream out) throws IOException {
		out.writeByte(_byte);
	}


	public final void read(DataInputStream in) throws IOException {
		_byte = in.readByte();
	}

	/**
	 * Diese Methode prüft auf Gleichheit eines Objektes, dass dieser Klasse entstammt. Die Prüfung erfolgt von "grob" nach "fein". Nach einer
	 * <code>null</code>-Referenzabfrage wird die Instanceof methode aufgerufen, abschließend wird der Inhalt des Objektes geprüft.
	 *
	 * @param obj Referenzobjekt
	 *
	 * @return true: objekt ist gleich, false: Objekt ist nicht gleich
	 */
	public final boolean equals(Object obj) {
		if(obj == null) {
			return false;
		}
		if(!(obj instanceof ByteAttribute)) {
			return false;
		}
		byte _b = ((Byte)((ByteAttribute)obj).getValue()).byteValue();
		return _byte == _b;
	}
}
